@@ -145,9 +145,8 @@ class Catalog_subsonic extends Catalog
      * Constructor
      *
      * Catalog class constructor, pulls catalog information
-     * @param int $catalog_id
      */
-    public function __construct($catalog_id = null)
+    public function __construct(?int $catalog_id = null)
     {
         if ($catalog_id) {
             $info = $this->get_info($catalog_id, static::DB_TABLENAME);
@@ -164,14 +163,17 @@ class Catalog_subsonic extends Catalog
      * This creates a new catalog type entry for a catalog
      * It checks to make sure its parameters is not already used before creating
      * the catalog.
-     * @param string $catalog_id
-     * @param array $data
+     * @param array{
+     *     uri?: string,
+     *     username?: ?string,
+     *     password?: ?string,
+     * } $data
      */
-    public static function create_type($catalog_id, $data): bool
+    public static function create_type(string $catalog_id, array $data): bool
     {
-        $uri      = rtrim(trim($data['uri']), '/');
-        $username = $data['username'];
-        $password = $data['password'];
+        $uri      = rtrim(trim($data['uri'] ?? ''), '/');
+        $username = $data['username'] ?? '';
+        $password = $data['password'] ?? '';
 
         if (substr($uri, 0, 7) != 'http://' && substr($uri, 0, 8) != 'https://') {
             AmpError::add('general', T_('Remote Catalog type was selected, but the path is not a URL'));
@@ -230,7 +232,7 @@ class Catalog_subsonic extends Catalog
      */
     public function createClient(): SubsonicClient
     {
-        return (new SubsonicClient($this->username, $this->password, $this->uri, 'Ampache'));
+        return (new SubsonicClient($this->username, $this->password, $this->uri));
     }
 
     /**
@@ -266,13 +268,21 @@ class Catalog_subsonic extends Catalog
 
                     if (is_array($album) && $album['success']) {
                         foreach ($album['data']['directory']['child'] as $song) {
-                            $artistInfo = $subsonic->querySubsonic('getArtistInfo', ['id' => $song['artistId']]);
+                            $artistInfo  = $subsonic->querySubsonic('getArtistInfo', ['id' => $song['artistId']]);
+                            $albumartist = $subsonic->querySubsonic('getArtist', ['id' => $album['data']['directory']['parent']]);
                             if (Catalog::is_audio_file($song['path'])) {
-                                $data           = [];
-                                $data['artist'] = html_entity_decode($song['artist']);
-                                $data['album']  = html_entity_decode($song['album']);
-                                $data['title']  = html_entity_decode($song['title']);
-                                if (is_array($artistInfo) && $artistInfo['Success']) {
+                                $data = [];
+                                // album_artist isn't included in the song response
+                                if (is_array($albumartist) && $albumartist['success']) {
+                                    $data['albumartist'] = html_entity_decode($albumartist['data']['artist']['name']);
+                                }
+                                $data['artist']      = html_entity_decode($song['artist']);
+                                $data['album']       = html_entity_decode($song['album']);
+                                $data['title']       = html_entity_decode($song['title']);
+                                if (
+                                    is_array($artistInfo) &&
+                                    isset($artistInfo['data']['artistInfo']['biography'])
+                                ) {
                                     $data['comment'] = html_entity_decode($artistInfo['data']['artistInfo']['biography']);
                                 }
                                 $data['year']     = $song['year'];
@@ -283,7 +293,9 @@ class Catalog_subsonic extends Catalog
                                 $data['disk']     = $song['discNumber'];
                                 $data['coverArt'] = $song['coverArt'];
                                 $data['mode']     = 'vbr';
-                                $data['genre']    = explode(' ', html_entity_decode($song['genre']));
+                                $data['genre']    = (!empty($song['genre']))
+                                    ? explode(',', html_entity_decode($song['genre']))
+                                    : [];
                                 $data['file']     = $this->uri . '/rest/stream.view?id=' . $song['id'] . '&filename=' . urlencode($song['path']);
                                 if ($this->check_remote_song($data)) {
                                     debug_event('subsonic.catalog', 'Skipping existing song ' . $song['path'], 5);
@@ -335,23 +347,19 @@ class Catalog_subsonic extends Catalog
     }
 
     /**
-     * @param $data
-     * @param int|null $song_Id
+     * @param array<string, mixed> $data
      */
-    public function insertArt($data, $song_Id): bool
+    public function insertArt(array $data, ?int $song_Id): bool
     {
         $subsonic = $this->createClient();
         $song     = new Song($song_Id);
         $art      = new Art($song->album, 'album');
         if (AmpConfig::get('album_art_max_height') && AmpConfig::get('album_art_max_width')) {
-            $size = [
-                'width' => AmpConfig::get('album_art_max_width'),
-                'height' => AmpConfig::get('album_art_max_height')
-            ];
+            $size = (int)max(AmpConfig::get('album_art_max_width'), AmpConfig::get('album_art_max_height'));
         } else {
-            $size = ['width' => 275, 'height' => 275];
+            $size = 275;
         }
-        $image = $subsonic->querySubsonic('getCoverArt', ['id' => $data['coverArt'], $size], true);
+        $image = $subsonic->querySubsonic('getCoverArt', ['id' => (string)$data['coverArt'], 'size' => $size], true);
 
         return (
             is_string($image) &&
@@ -400,7 +408,7 @@ class Catalog_subsonic extends Catalog
     /**
      * @return string[]
      */
-    public function check_catalog_proc(): array
+    public function check_catalog_proc(?Interactor $interactor = null): array
     {
         return [];
     }
@@ -496,12 +504,15 @@ class Catalog_subsonic extends Catalog
      *
      * checks to see if a remote song exists in the database or not
      * if it find a song it returns the UID
-     * @param array $song
+     * @param array<string, mixed> $song
      */
-    public function check_remote_song($song): ?int
+    public function check_remote_song(array $song): ?int
     {
-        $url = $song['file'];
+        if (!isset($song['file'])) {
+            return null;
+        }
 
+        $url        = $song['file'];
         $sql        = 'SELECT `id` FROM `song` WHERE `file` = ?';
         $db_results = Dba::read($sql, [$url]);
 
@@ -522,10 +533,7 @@ class Catalog_subsonic extends Catalog
         return (str_replace($catalog_path . "/", "", $file_path));
     }
 
-    /**
-     * @param string $url
-     */
-    public function url_to_songid($url): int
+    public function url_to_songid(string $url): int
     {
         $song_id = 0;
         preg_match('/\?id=([0-9]*)&/', $url, $matches);
@@ -537,11 +545,11 @@ class Catalog_subsonic extends Catalog
     }
 
     /**
-     * format
+     * get_f_info
      */
-    public function format(): void
+    public function get_f_info(): string
     {
-        $this->f_info = $this->uri;
+        return $this->uri;
     }
 
     /**
