@@ -45,8 +45,10 @@ use Ampache\Module\Util\ObjectTypeToClassNameMapper;
  */
 class AmpacheMpd extends localplay_controller
 {
-    /* Variables */
-    private string $version     = '000003';
+    public bool $block_clear = false;
+
+    private string $version = '000003';
+
     private string $description = 'Controls an instance of MPD';
 
     private int $_add_count = 0;
@@ -153,9 +155,8 @@ class AmpacheMpd extends localplay_controller
      */
     public function delete_instance(int $uid): void
     {
-        $uid = Dba::escape($uid);
-        $sql = "DELETE FROM `localplay_mpd` WHERE `id`='$uid'";
-        Dba::write($sql);
+        $sql = "DELETE FROM `localplay_mpd` WHERE `id` = ?";
+        Dba::write($sql, [$uid]);
     }
 
     /**
@@ -281,11 +282,12 @@ class AmpacheMpd extends localplay_controller
      */
     public function add_url(Stream_Url $url): bool
     {
-        // If we haven't added anything then maybe we should clear the
-        // playlist.
+        // If we haven't added anything then maybe we should clear the playlist.
         if ($this->_add_count < 1) {
             $this->_mpd->RefreshInfo();
-            if ($this->_mpd->status['state'] == mpd::STATE_STOPPED) {
+            if ($this->block_clear === false &&
+                $this->_mpd->status['state'] == mpd::STATE_STOPPED
+            ) {
                 $this->clear_playlist();
             }
         }
@@ -317,6 +319,8 @@ class AmpacheMpd extends localplay_controller
      */
     public function clear_playlist(): bool
     {
+        $this->_add_count = 0;
+
         return $this->_mpd->PLClear() !== false;
     }
 
@@ -403,7 +407,6 @@ class AmpacheMpd extends localplay_controller
     /**
      * volume
      * This tells MPD to set the volume to the parameter
-     * @param $volume
      */
     public function volume($volume): bool
     {
@@ -485,9 +488,8 @@ class AmpacheMpd extends localplay_controller
 
             switch ($url_key) {
                 case 'oid':
-                    $data['oid'] = (int)$url_data['oid'];
-                    $song        = new Song($data['oid']);
-                    $song->format();
+                    $data['oid']  = (int)$url_data['oid'];
+                    $song         = new Song($data['oid']);
                     $data['name'] = $song->get_fullname() . ' - ' . $song->get_album_fullname($song->album, true) . ' - ' . $song->get_artist_fullname();
                     $data['link'] = $song->get_f_link();
                     break;
@@ -506,14 +508,13 @@ class AmpacheMpd extends localplay_controller
                 default:
                     // If we don't know it, look up by filename
                     $filename = Dba::escape($entry['file']);
-                    $sql      = "SELECT `id`, 'song' AS `type` FROM `song` WHERE `file` LIKE '%$filename' UNION ALL SELECT `id`, 'live_stream' AS `type` FROM `live_stream` WHERE `url`='$filename' ";
+                    $sql      = "SELECT `id`, 'song' AS `type` FROM `song` WHERE `file` LIKE ? UNION ALL SELECT `id`, 'live_stream' AS `type` FROM `live_stream` WHERE `url` = ? ";
 
-                    $db_results = Dba::read($sql);
+                    $db_results = Dba::read($sql, ['%' . $filename, $filename]);
                     if ($row = Dba::fetch_assoc($db_results)) {
                         $className = ObjectTypeToClassNameMapper::map($row['type']);
                         /** @var Song|Live_Stream $media */
                         $media = new $className($row['id']);
-                        $media->format();
                         switch ($row['type']) {
                             case 'song':
                                 /** @var Song $media */
